(this["webpackJsonp@dagit/app"]=this["webpackJsonp@dagit/app"]||[]).push([[9],{461:function(e,t,n){"use strict";n.d(t,"a",(function(){return i}));var c=n(0),i=function(e){c.useEffect((function(){var t=document.title;return document.title=e,function(){document.title=t}}),[e])}},952:function(e,t,n){"use strict";n.r(t),n.d(t,"FeatureFlagsRoot",(function(){return d}));var c=n(20),i=n(16),u=n(27),o=n(0),a=n(461),r=n(47),s=n(1),d=function(){var e=o.useState(Object(r.k)()),t=Object(i.a)(e,2),n=t[0],d=t[1];o.useEffect((function(){Object(r.n)(n)})),Object(a.a)("Feature Flags");return Object(s.jsxs)("div",{style:{padding:30,paddingTop:0},children:[Object(s.jsx)("h4",{children:"Experimental Features"}),Object(s.jsx)("div",{children:Object(s.jsx)(u.d,{label:"Debug Console Logging",checked:n.includes(r.b.DebugConsoleLogging),onChange:function(){return e=r.b.DebugConsoleLogging,void d(n.includes(e)?n.filter((function(t){return t!==e})):[].concat(Object(c.a)(n),[e]));var e}})})]})};t.default=d}}]);
//# sourceMappingURL=9.2ad87d6e.chunk.js.map